@@ -229,6 +229,8 @@ class GeneratedsSuper(object):
             raise_parse_error(node, 'Requires integer value')
         return value
     def gds_format_integer_list(self, input_data, input_name=''):
+        if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+            input_data = [str(s) for s in input_data]
         return '%s' % ' '.join(input_data)
     def gds_validate_integer_list(
             self, input_data, node=None, input_name=''):
@@ -254,6 +256,8 @@ class GeneratedsSuper(object):
             raise_parse_error(node, 'Requires float value')
         return value
     def gds_format_float_list(self, input_data, input_name=''):
+        if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+            input_data = [str(s) for s in input_data]
         return '%s' % ' '.join(input_data)
     def gds_validate_float_list(
             self, input_data, node=None, input_name=''):
@@ -284,6 +288,8 @@ class GeneratedsSuper(object):
             raise_parse_error(node, 'Requires decimal value')
         return value
     def gds_format_decimal_list(self, input_data, input_name=''):
+        if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+            input_data = [str(s) for s in input_data]
         return ' '.join([self.gds_format_decimal(item) for item in input_data])
     def gds_validate_decimal_list(
             self, input_data, node=None, input_name=''):
@@ -309,6 +315,8 @@ class GeneratedsSuper(object):
             raise_parse_error(node, 'Requires double or float value')
         return value
     def gds_format_double_list(self, input_data, input_name=''):
+        if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+            input_data = [str(s) for s in input_data]
         return '%s' % ' '.join(input_data)
     def gds_validate_double_list(
             self, input_data, node=None, input_name=''):
@@ -338,6 +346,8 @@ class GeneratedsSuper(object):
                 '(one of True, 1, False, 0)')
         return input_data
     def gds_format_boolean_list(self, input_data, input_name=''):
+        if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+            input_data = [str(s) for s in input_data]
         return '%s' % ' '.join(input_data)
     def gds_validate_boolean_list(
             self, input_data, node=None, input_name=''):
