@@ -220,6 +220,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires integer value')
             return value
         def gds_format_integer_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_integer_list(
                 self, input_data, node=None, input_name=''):
@@ -245,6 +247,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires float value')
             return value
         def gds_format_float_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_float_list(
                 self, input_data, node=None, input_name=''):
@@ -275,6 +279,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
@@ -300,6 +306,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires double or float value')
             return value
         def gds_format_double_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_double_list(
                 self, input_data, node=None, input_name=''):
@@ -329,6 +337,8 @@ except ModulenotfoundExp_ as exp:
                     '(one of True, 1, False, 0)')
             return input_data
         def gds_format_boolean_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_boolean_list(
                 self, input_data, node=None, input_name=''):
@@ -1401,7 +1411,8 @@ class USAddress(Address):
         self.ns_prefix_ = None
         super(USAddress, self).__init__(name, street, city,  **kwargs_)
         self.state = state
-        self.validate_USState(self.state)
+        if self.state is not None:
+            self.validate_USState(self.state)
         self.state_nsprefix_ = None
         self.zip = zip
         self.zip_nsprefix_ = None
@@ -1543,7 +1554,8 @@ class UKAddress(Address):
         self.exportCode = _cast(int, exportCode)
         self.exportCode_nsprefix_ = None
         self.postcode = postcode
-        self.validate_UKPostcode(self.postcode)
+        if self.postcode is not None:
+            self.validate_UKPostcode(self.postcode)
         self.postcode_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
@@ -1682,7 +1694,8 @@ class itemType(GeneratedsSuper):
         self.productName = productName
         self.productName_nsprefix_ = None
         self.quantity = quantity
-        self.validate_quantityType(self.quantity)
+        if self.quantity is not None:
+            self.validate_quantityType(self.quantity)
         self.quantity_nsprefix_ = None
         self.USPrice = USPrice
         self.USPrice_nsprefix_ = None
