@@ -222,6 +222,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires integer value')
             return value
         def gds_format_integer_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_integer_list(
                 self, input_data, node=None, input_name=''):
@@ -247,6 +249,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires float value')
             return value
         def gds_format_float_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_float_list(
                 self, input_data, node=None, input_name=''):
@@ -277,6 +281,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
@@ -302,6 +308,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires double or float value')
             return value
         def gds_format_double_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_double_list(
                 self, input_data, node=None, input_name=''):
@@ -331,6 +339,8 @@ except ModulenotfoundExp_ as exp:
                     '(one of True, 1, False, 0)')
             return input_data
         def gds_format_boolean_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_boolean_list(
                 self, input_data, node=None, input_name=''):
@@ -973,7 +983,7 @@ def _cast(typ, value):
 #
 
 
-class Wheel1(GeneratedsSuper):
+class Wheel(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
         MemberSpec_('description', 'string', 0, 0, {'name': 'description', 'type': 'string'}, None),
@@ -990,18 +1000,19 @@ class Wheel1(GeneratedsSuper):
         self.description = description
         self.description_nsprefix_ = None
         self.radius = radius
-        self.validate_radiusType(self.radius)
+        if self.radius is not None:
+            self.validate_radiusType(self.radius)
         self.radius_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, Wheel1)
+                CurrentSubclassModule_, Wheel)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if Wheel1.subclass:
-            return Wheel1.subclass(*args_, **kwargs_)
+        if Wheel.subclass:
+            return Wheel.subclass(*args_, **kwargs_)
         else:
-            return Wheel1(*args_, **kwargs_)
+            return Wheel(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
@@ -1036,32 +1047,32 @@ class Wheel1(GeneratedsSuper):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='Wheel1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('Wheel1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='Wheel', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('Wheel')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'Wheel1':
+        if self.original_tagname_ is not None and name_ == 'Wheel':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='Wheel1')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='Wheel')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='Wheel1', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='Wheel', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='Wheel1'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='Wheel'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='Wheel1', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='xmlns:tns="http://www.example.org/wheel/" xmlns:None="http://www.w3.org/2001/XMLSchema" ', name_='Wheel', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
@@ -1106,11 +1117,11 @@ class Wheel1(GeneratedsSuper):
             self.radius_nsprefix_ = child_.prefix
             # validate type radiusType
             self.validate_radiusType(self.radius)
-# end class Wheel1
+# end class Wheel
 
 
 GDSClassesMapping = {
-    'Wheel': Wheel1,
+    'Wheel': Wheel,
 }
 
 
@@ -1157,8 +1168,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'Wheel1'
-        rootClass = Wheel1
+        rootTag = 'Wheel'
+        rootClass = Wheel
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1189,8 +1200,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'Wheel1'
-        rootClass = Wheel1
+        rootTag = 'Wheel'
+        rootClass = Wheel
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1232,8 +1243,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'Wheel1'
-        rootClass = Wheel1
+        rootTag = 'Wheel'
+        rootClass = Wheel
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1260,8 +1271,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'Wheel1'
-        rootClass = Wheel1
+        rootTag = 'Wheel'
+        rootClass = Wheel
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1297,7 +1308,6 @@ if __name__ == '__main__':
     main()
 
 RenameMappings_ = {
-    "{http://www.example.org/wheel/}Wheel": "Wheel1",
 }
 
 #
@@ -1309,5 +1319,5 @@ NamespaceToDefMappings_ = {'http://www.example.org/wheel/': [('Wheel',
                                     'CT')]}
 
 __all__ = [
-    "Wheel1"
+    "Wheel"
 ]
