@@ -221,6 +221,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires integer value')
             return value
         def gds_format_integer_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_integer_list(
                 self, input_data, node=None, input_name=''):
@@ -246,6 +248,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires float value')
             return value
         def gds_format_float_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_float_list(
                 self, input_data, node=None, input_name=''):
@@ -276,6 +280,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
@@ -301,6 +307,8 @@ except ModulenotfoundExp_ as exp:
                 raise_parse_error(node, 'Requires double or float value')
             return value
         def gds_format_double_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_double_list(
                 self, input_data, node=None, input_name=''):
@@ -330,6 +338,8 @@ except ModulenotfoundExp_ as exp:
                     '(one of True, 1, False, 0)')
             return input_data
         def gds_format_boolean_list(self, input_data, input_name=''):
+            if len(input_data) > 0 and not isinstance(input_data[0], BaseStrType_):
+                input_data = [str(s) for s in input_data]
             return '%s' % ' '.join(input_data)
         def gds_validate_boolean_list(
                 self, input_data, node=None, input_name=''):
@@ -963,7 +973,7 @@ def _cast(typ, value):
 class PersonType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('personId', 'PersonIdType1', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
+        MemberSpec_('personId', 'PersonIdType', 0, 0, {'maxOccurs': '1', 'minOccurs': '1', 'name': 'personId', 'ref': 'personId', 'type': 'personId'}, None),
         MemberSpec_('fname', 'xs:string', 0, 0, {'name': 'fname', 'type': 'xs:string'}, None),
         MemberSpec_('lname', 'xs:string', 0, 0, {'name': 'lname', 'type': 'xs:string'}, None),
     ]
@@ -1073,7 +1083,7 @@ class PersonType(GeneratedsSuper):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if nodeName_ == 'personId':
-            obj_ = PersonIdType1.factory(parent_object_=self)
+            obj_ = PersonIdType.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.personId = obj_
             obj_.original_tagname_ = 'personId'
@@ -1092,10 +1102,10 @@ class PersonType(GeneratedsSuper):
 # end class PersonType
 
 
-class PersonIdType1(GeneratedsSuper):
+class PersonIdType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('valueOf_', ['PersonIdType', 'eitc:IdType'], 0),
+        MemberSpec_('valueOf_', ['PersonIdType_impl', 'IdType', 'xs:integer'], 0),
     ]
     subclass = None
     superclass = None
@@ -1109,13 +1119,13 @@ class PersonIdType1(GeneratedsSuper):
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, PersonIdType1)
+                CurrentSubclassModule_, PersonIdType)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if PersonIdType1.subclass:
-            return PersonIdType1.subclass(*args_, **kwargs_)
+        if PersonIdType.subclass:
+            return PersonIdType.subclass(*args_, **kwargs_)
         else:
-            return PersonIdType1(*args_, **kwargs_)
+            return PersonIdType(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
@@ -1130,32 +1140,32 @@ class PersonIdType1(GeneratedsSuper):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('PersonIdType1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('PersonIdType')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'PersonIdType1':
+        if self.original_tagname_ is not None and name_ == 'PersonIdType':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PersonIdType1')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='PersonIdType')
         if self.hasContent_():
             outfile.write('>')
             outfile.write(self.convert_unicode(self.valueOf_))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PersonIdType1', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='PersonIdType', pretty_print=pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='PersonIdType1'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='PersonIdType'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType1', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='PersonIdType', fromsubclass_=False, pretty_print=True):
         pass
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
@@ -1173,12 +1183,12 @@ class PersonIdType1(GeneratedsSuper):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         pass
-# end class PersonIdType1
+# end class PersonIdType
 
 
 GDSClassesMapping = {
     'person': PersonType,
-    'personId': PersonIdType1,
+    'personId': PersonIdType,
 }
 
 
@@ -1374,6 +1384,6 @@ RenameMappings_ = {
 NamespaceToDefMappings_ = {}
 
 __all__ = [
-    "PersonIdType1",
+    "PersonIdType",
     "PersonType"
 ]
